@@ -47,12 +47,6 @@ sub content_like {
   return $self->_test('like', $self->tx->res->text, $regex, $desc);
 }
 
-sub content_unlike {
-  my ($self, $regex, $desc) = @_;
-  $desc ||= 'content is not similar';
-  return $self->_test('unlike', $self->tx->res->text, $regex, $desc);
-}
-
 sub content_type_is {
   my ($self, $type, $desc) = @_;
   $desc ||= "Content-Type: $type";
@@ -81,6 +75,12 @@ sub content_type_unlike {
     $regex, $desc);
 }
 
+sub content_unlike {
+  my ($self, $regex, $desc) = @_;
+  $desc ||= 'content is not similar';
+  return $self->_test('unlike', $self->tx->res->text, $regex, $desc);
+}
+
 sub delete_ok { shift->_build_ok(DELETE => @_) }
 
 sub element_count_is {
@@ -510,6 +510,11 @@ User agent used for testing, defaults to a L<Mojo::UserAgent> object.
 
   # Allow redirects
   $t->ua->max_redirects(10);
+  $t->get_ok('/redirect')->status_is(200)->content_like(qr/redirected/);
+
+  # Switch protocol from HTTP to HTTPS
+  $t->ua->server->url('https');
+  $t->get_ok('/secure')->status_is(200)->content_like(qr/secure/);
 
   # Use absolute URL for request with Basic authentication
   my $url = $t->ua->server->url->userinfo('sri:secr3t')->path('/secrets.json');
@@ -522,6 +527,7 @@ User agent used for testing, defaults to a L<Mojo::UserAgent> object.
     my ($ua, $tx) = @_;
     $tx->req->headers->accept_language('en-US');
   });
+  $t->get_ok('/hello')->status_is(200)->content_like(qr/Howdy/);
 
 =head1 METHODS
 
@@ -552,10 +558,13 @@ Access application with L<Mojo::UserAgent::Server/"app">.
     $c->render(text => 'This request did not reach the router.')
       if $c->req->url->path->contains('/user');
   });
+  $t->get_ok('/user')->status_is(200)->content_like(qr/not reach the router/);
 
   # Extract additional information
   my $stash;
   $t->app->hook(after_dispatch => sub { $stash = shift->stash });
+  $t->get_ok('/hello')->status_is(200);
+  is $stash->{foo}, 'bar', 'right value';
 
 =head2 content_is
 
@@ -580,13 +589,6 @@ Opposite of L</"content_is">.
 Check response content for similar match after retrieving it from
 L<Mojo::Message/"text">.
 
-=head2 content_unlike
-
-  $t = $t->content_unlike(qr/working!/);
-  $t = $t->content_unlike(qr/working!/, 'different content');
-
-Opposite of L</"content_like">.
-
 =head2 content_type_is
 
   $t = $t->content_type_is('text/html');
@@ -615,6 +617,13 @@ Check response C<Content-Type> header for similar match.
 
 Opposite of L</"content_type_like">.
 
+=head2 content_unlike
+
+  $t = $t->content_unlike(qr/working!/);
+  $t = $t->content_unlike(qr/working!/, 'different content');
+
+Opposite of L</"content_like">.
+
 =head2 delete_ok
 
   $t = $t->delete_ok('/foo');
